aboutsummaryrefslogtreecommitdiff
path: root/gcc/fortran/simplify.cc
diff options
context:
space:
mode:
authorTobias Burnus <tobias@codesourcery.com>2023-04-28 09:23:18 +0200
committerTobias Burnus <tobias@codesourcery.com>2023-04-28 09:23:18 +0200
commit7ebd4a1d61993c0a75e9ff3098aded21ef04a4da (patch)
treed641ff976f89796d8dce005d9e24c81b03fbbadd /gcc/fortran/simplify.cc
parentba39d2be0bab29cfb68cdb845b98353d11442244 (diff)
downloadgcc-7ebd4a1d61993c0a75e9ff3098aded21ef04a4da.zip
gcc-7ebd4a1d61993c0a75e9ff3098aded21ef04a4da.tar.gz
gcc-7ebd4a1d61993c0a75e9ff3098aded21ef04a4da.tar.bz2
Fortran: Fix (mostly) comment typos
Only other changes are fixing the variable name a(b)breviated_modproc_decl and a few typos in gfortran.texi. gcc/fortran/ChangeLog: * gfortran.texi: Fix typos. * decl.cc: Fix typos in comments and in a variable name. * arith.cc: Fix comment typos. * check.cc: Likewise. * class.cc: Likewise. * dependency.cc: Likewise. * expr.cc: Likewise. * frontend-passes.cc: Likewise. * gfortran.h: Likewise. * intrinsic.cc: Likewise. * iresolve.cc: Likewise. * match.cc: Likewise. * module.cc: Likewise. * primary.cc: Likewise. * resolve.cc: Likewise. * simplify.cc: Likewise. * trans-array.cc: Likewise. * trans-decl.cc: Likewise. * trans-expr.cc: Likewise. * trans-intrinsic.cc: Likewise. * trans-openmp.cc: Likewise. * trans-stmt.cc: Likewise.
Diffstat (limited to 'gcc/fortran/simplify.cc')
-rw-r--r--gcc/fortran/simplify.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/fortran/simplify.cc b/gcc/fortran/simplify.cc
index b65854c..7b06421 100644
--- a/gcc/fortran/simplify.cc
+++ b/gcc/fortran/simplify.cc
@@ -4130,11 +4130,11 @@ simplify_bound_dim (gfc_expr *array, gfc_expr *kind, int d, int upper,
/* For {L,U}BOUND, the value depends on whether the array
is empty. We can nevertheless simplify if the declared bound
has the same value as that of an empty array, in which case
- the result isn't dependent on the array emptyness. */
+ the result isn't dependent on the array emptiness. */
if (mpz_cmp_si (declared_bound->value.integer, empty_bound) == 0)
mpz_set_si (result->value.integer, empty_bound);
else if (!constant_lbound || !constant_ubound)
/* Array emptyness can't be determined, we can't simplify. */
goto returnNull;
else if (mpz_cmp (l->value.integer, u->value.integer) > 0)
mpz_set_si (result->value.integer, empty_bound);
@@ -4130,11 +4130,11 @@ simplify_bound_dim (gfc_expr *array, gfc_expr *kind, int d, int upper,
mpz_set_si (result->value.integer, empty_bound);
else if (!constant_lbound || !constant_ubound)
- /* Array emptyness can't be determined, we can't simplify. */
+ /* Array emptiness can't be determined, we can't simplify. */
goto returnNull;
else if (mpz_cmp (l->value.integer, u->value.integer) > 0)